instrumenttools.notes_and_chords_are_on_expected_clefs
======================================================

.. autofunction:: abjad.tools.instrumenttools.notes_and_chords_are_on_expected_clefs.notes_and_chords_are_on_expected_clefs
